==> app-facade-2.0.3-sources.jar: com/bxm/app/facade/AppEntranceFacadeService.java <==
/*
 * Copyright 2018 bianxianmao.com All right reserved. This software is the confidential and proprietary information of
 * bianxianmao.com ("Confidential Information"). You shall not disclose such Confidential Information and shall use it
 * only in accordance with the terms of the license agreement you entered into with bianxianmao.com.
 */
package com.bxm.app.facade;

import java.util.List;

import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.bxm.app.model.dto.AppEntranceAdDto;
import com.bxm.app.model.dto.AuditAdPositionDto;
import com.bxm.app.model.ro.AppEntranceAdRo;
import com.bxm.util.dto.ResultModel;
import com.bxm.util.dto.ValidateException;
import com.github.pagehelper.PageInfo;

/**
 * @ClassName AppEntranceFacadeService.java
 * @Description 功能描述：广告位相关接口
 * @author leon 2018年3月12日 下午3:26:23
 * @CopyRight 杭州微财网络科技有限公司
 */
@FeignClient(name = "app")
public interface AppEntranceFacadeService {

    /**
     * @Description 方法描述：修改开发者广告位相关信息，修改备注，别名，行业类型
     * @author leon 2018年3月12日 下午4:20:18
     * @CopyRight 杭州微财网络科技有限公司
     * @param appEntranceDto
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/updateAdPositionInfo", method = RequestMethod.PUT)
    public ResultModel<Boolean> updateAdPositionInfo(@RequestBody AppEntranceAdDto appEntranceDto) throws ValidateException,
                                                                                                   Exception;

    /**
     * @Description 方法描述：根据positionId查询广告位信息，返回开发者名称,行业类型,备注,别名等信息
     * @author leon 2018年3月12日 下午4:20:45
     * @CopyRight 杭州微财网络科技有限公司
     * @param positionId
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/getByPositionId", method = RequestMethod.GET)
    public ResultModel<AppEntranceAdRo> getByPositionId(@RequestParam(value = "positionId", required = true) String positionId) throws ValidateException,
                                                                                                                                Exception;

    /**
     * @Description 方法描述：根据关键字查询列表，默认查询全部
     * @author leon 2018年3月12日 下午4:21:09
     * @CopyRight 杭州微财网络科技有限公司
     * @param positionId 广告位id
     * @param keywords 关键字：BD,媒介,备注
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/getList", method = RequestMethod.GET)
    public ResultModel<List<AppEntranceAdRo>> getList(@RequestParam(value = "positionId", required = false) String positionId,
                                                      @RequestParam(value = "keyword", required = false) String keywords) throws ValidateException,
                                                                                                                          Exception;

    /**
     * @Description 方法描述：查询审核列表
     * @author leon 2018年4月2日 下午3:35:32
     * @CopyRight 杭州微财网络科技有限公司
     * @param pageNum
     * @param pageSize
     * @param positionId
     * @param keywords
     * @param state
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/getAuditList", method = RequestMethod.GET)
    public ResultModel<PageInfo<AppEntranceAdRo>> getAuditList(@RequestParam(value = "pageNum", required = true) Integer pageNum,
                                                               @RequestParam(value = "pageSize", required = true) Integer pageSize,
                                                               @RequestParam(value = "positionId", required = false) String positionId,
                                                               @RequestParam(value = "keyword", required = false) String keywords,
                                                               @RequestParam(value = "state", required = false) Integer state) throws ValidateException,
                                                                                                                               Exception;

    /**
     * @Description 方法描述：审核广告位信息
     * @author leon 2018年4月2日 下午3:56:34
     * @CopyRight 杭州微财网络科技有限公司
     * @param auditAdPositionDto
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/auditAdPosition", method = RequestMethod.PUT)
    public ResultModel<Boolean> auditAdPosition(@RequestBody AuditAdPositionDto auditAdPositionDto) throws ValidateException,
                                                                                                    Exception;

    /**
     *
     * @CopyRright  (c) 2018-微财科技有限公司
     * @author sunzhongshu
     * @created 2018/6/4 15:18
     * @modifier sunzhongshu
     */

    @ApiOperation(value = "不分页根据单个媒体下面的广告位列表",notes = "不分页根据单个媒体下面的广告位列表")
    @RequestMapping(value = "/appEntranceFacade/getPositionIdList",method = RequestMethod.GET)
    public ResultModel<List<AppEntranceAdRo>> getPositionIdList(@RequestParam(value = "state", required = false) Integer state,
                                                                @RequestParam(value = "appKey",required = true) String appKey) throws ValidateException,Exception;

}

==> app-facade-2.0.9-20180815.081823-1-sources.jar: com/bxm/app/facade/AppEntranceFacadeService.java <==
/*
 * Copyright 2018 bianxianmao.com All right reserved. This software is the confidential and proprietary information of
 * bianxianmao.com ("Confidential Information"). You shall not disclose such Confidential Information and shall use it
 * only in accordance with the terms of the license agreement you entered into with bianxianmao.com.
 */
package com.bxm.app.facade;

import com.bxm.app.model.dto.AppEntranceAdDto;
import com.bxm.app.model.dto.AuditAdPositionDto;
import com.bxm.app.model.ro.AppEntranceAdRo;
import com.bxm.util.dto.ResultModel;
import com.bxm.util.dto.ValidateException;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @ClassName AppEntranceFacadeService.java
 * @Description 功能描述：广告位相关接口
 * @author leon 2018年3月12日 下午3:26:23
 * @CopyRight 杭州微财网络科技有限公司
 */
@FeignClient(name = "app")
public interface AppEntranceFacadeService {

    /**
     * @Description 方法描述：修改开发者广告位相关信息，修改备注，别名，行业类型
     * @author leon 2018年3月12日 下午4:20:18
     * @CopyRight 杭州微财网络科技有限公司
     * @param appEntranceDto
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/updateAdPositionInfo", method = RequestMethod.PUT)
    public ResultModel<Boolean> updateAdPositionInfo(@RequestBody AppEntranceAdDto appEntranceDto) throws ValidateException,
                                                                                                   Exception;

    /**
     * @Description 方法描述：根据positionId查询广告位信息，返回开发者名称,行业类型,备注,别名等信息
     * @author leon 2018年3月12日 下午4:20:45
     * @CopyRight 杭州微财网络科技有限公司
     * @param positionId
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/getByPositionId", method = RequestMethod.GET)
    public ResultModel<AppEntranceAdRo> getByPositionId(@RequestParam(value = "positionId", required = true) String positionId) throws ValidateException,
                                                                                                                                Exception;

    /**
     * @Description 方法描述：根据关键字查询列表，默认查询全部
     * @author leon 2018年3月12日 下午4:21:09
     * @CopyRight 杭州微财网络科技有限公司
     * @param positionId 广告位id
     * @param keywords 关键字：BD,媒介,备注
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/getList", method = RequestMethod.GET)
    public ResultModel<List<AppEntranceAdRo>> getList(@RequestParam(value = "positionId", required = false) String positionId,
                                                      @RequestParam(value = "keyword", required = false) String keywords) throws ValidateException,
                                                                                                                          Exception;

    /**
     * @Description 方法描述：查询审核列表
     * @author leon 2018年4月2日 下午3:35:32
     * @CopyRight 杭州微财网络科技有限公司
     * @param pageNum
     * @param pageSize
     * @param positionId
     * @param keywords
     * @param state
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/getAuditList", method = RequestMethod.GET)
    public ResultModel<PageInfo<AppEntranceAdRo>> getAuditList(@RequestParam(value = "pageNum", required = true) Integer pageNum,
                                                               @RequestParam(value = "pageSize", required = true) Integer pageSize,
                                                               @RequestParam(value = "positionId", required = false) String positionId,
                                                               @RequestParam(value = "keyword", required = false) String keywords,
                                                               @RequestParam(value = "state", required = false) Integer state) throws ValidateException,
                                                                                                                               Exception;

    /**
     * @Description 方法描述：审核广告位信息
     * @author leon 2018年4月2日 下午3:56:34
     * @CopyRight 杭州微财网络科技有限公司
     * @param auditAdPositionDto
     * @return
     * @throws ValidateException
     * @throws Exception
     */
    @RequestMapping(value = "/appEntranceFacade/auditAdPosition", method = RequestMethod.PUT)
    public ResultModel<Boolean> auditAdPosition(@RequestBody AuditAdPositionDto auditAdPositionDto) throws ValidateException,
                                                                                                    Exception;

    /**
     *
     * @CopyRright  (c) 2018-微财科技有限公司
     * @author sunzhongshu
     * @created 2018/6/4 15:18
     * @modifier sunzhongshu
     */

    @ApiOperation(value = "不分页根据单个媒体下面的广告位列表",notes = "不分页根据单个媒体下面的广告位列表")
    @RequestMapping(value = "/appEntranceFacade/getPositionIdList",method = RequestMethod.GET)
    public ResultModel<List<AppEntranceAdRo>> getPositionIdList(@RequestParam(value = "state", required = false) Integer state,
                                                                @RequestParam(value = "appKey",required = true) String appKey) throws ValidateException,Exception;

    /**
     * 查询对接方式, 0为h5
     * @param appKey
     * @param appEntranceId
     * @return
     */
    @RequestMapping(value = "/appEntranceFacade/queryDockMethod", method = RequestMethod.GET)
    ResultModel<Integer> queryDockMethod(@RequestParam("appKey") String appKey, @RequestParam("appEntranceId") String appEntranceId);
}
